# Turbo Text Transformer Prompts

Designed for use with [turbo-text-transformer](https://github.com/fergusfettes/turbo-text-transformer).

You pipe some text in, the template is applied, then you pipe it into `ttt` which will process it with eg. OpenAI.

```
cat pyproject.toml tttp/__main__.py | tttp -t readme | ttt > README.md
```

Turbo Text Transformer Prompts is a command-line tool that allows users to generate text files from pre-configured templates using user input prompts. The tool uses Jinja2 templating engine to render text files from templates.

## How to Run

```sh
pip install turbo-text-transformer-prompts
```

You will also need to clone the repository containing the templates you want to use. For example:

```sh
mkdir -p ~/.config/ttt/
git clone https://github.com/fergusfettes/turbo-text-transformer-prompts ~/.config/ttt/tttp
```

## Template Structure

A template is a text file written in Jinja2 syntax. The file should have the `.j2` extension and be placed inside the `templates` directory.

The template can contain placeholders for user input. Placeholders are enclosed in double curly braces and contain a variable name. For example:

```jinja
Hello, {{ name }}!
```

This template will prompt the user to enter a value for the `name` variable.

## Prompt Files

Prompt files can be used to predefine the values to be filled in the template. Prompt files are text files that contain a prompt message followed by the values to be filled, one per line. For example:

```
Please enter your name:
John Doe
```

To use a prompt file, specify the file using the `--prompt` option:

```sh
tttp --filename simple --prompt /path/to/prompt/file
```

If there are any values that need to be added or changed from

## Contributing

If you find a bug or would like to contribute to Turbo Text Transformer Prompts, please create a new GitHub issue or pull request.

#  License

Turbo Text Transformer Prompts is licensed under the MIT License. See the [LICENSE](./LICENSE) file for details.
